<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="xml" indent="yes"/>

	<xsl:template match="
								subdomain/sysuser 
								| subdomain/@hosting-type
								| sb-domain
								| sb-reseller
								| sb-config
								| template-item[@name = 'publish-sb-site']
								| template-item[@name = 'sb_publish']
								| template-item[@name = 'sb_subdomains']
								| template-item[@name = 'use_sbnet']
								| template-item[@name = 'same_ssl']
								| template-item[@name = 'dashboard']
								| template-item[@name = 'manage_dashboard']
								| template-item[@name = 'stdgui']
								| template-item[@name = 'change_limits']
								| template-item[@name = 'site_builder']
								| template-item[@name = 'max_mg']
								| template-item[@name = 'max_redir']
								| template-item[@name = 'max_resp']
								| limit[@name = 'max_mg']
								| limit[@name = 'max_redir']
								| limit[@name = 'max_resp']
								| permission[@name = 'dashboard']
								| permission[@name = 'manage_dashboard']
								| permission[@name = 'stdgui']
								| permission[@name = 'change_limits']
								| permission[@name = 'site_builder']
								| cid[@type = 'sb-domain']
								| cid[@type = 'sb-reseller']
								| domain-template/template-item[@name = 'cp_access']
								| domain-template/template-item[@name = 'remote_access_interface']
								| domain-template/@shared
								| client-template
								| mailuser/@max-button-length
								| mailuser/@skin
								| mailuser/@lock-screen
								| mailuser/limits-and-permissions
								| mailuser/custom-button
								| autoresponder/@name
								| autoresponder/@require
								| autoresponder/@replyto
								| autoresponder/autoresponder-limit
								| domain/domainuser
								| client/limits-and-permissions
								| controls-visibility/hide-disabled-buttons
								| controls-visibility/hide-disabled-limits
								| controls-visibility/hide-disabled-permissions
								| server/keys/key[@additional = 'false']
								">
	</xsl:template>

	<xsl:template match="domain/limits-and-permissions">
		<xsl:copy>
			<xsl:apply-templates select="limit"/>
			<xsl:apply-templates select="permission"/>
			<xsl:if test="local-name(../../..)">
				<xsl:apply-templates select="../../../limits-and-permissions/permission"/>
			</xsl:if>
		</xsl:copy>
	</xsl:template>

	<xsl:template match="domain/properties/status[count(disabled-by) > 0]">
		<xsl:element name="webspace-status">
			<xsl:apply-templates select="@*|node()" />
		</xsl:element>
		<xsl:copy>
			<xsl:element name="disabled-by">
				<xsl:attribute name="name">
					<xsl:text>parent</xsl:text>
				</xsl:attribute>
			</xsl:element>
		</xsl:copy>
	</xsl:template>
	
	<xsl:template match="domain/phosting">
		<xsl:copy>
			<xsl:if test="count(@shared-content) = 0">
				<xsl:attribute name="shared-content">
					<xsl:text>false</xsl:text>
				</xsl:attribute>
			</xsl:if>
			<xsl:attribute name="www-root">
				<xsl:text>httpdocs</xsl:text>
			</xsl:attribute>
			<xsl:apply-templates select="@*|node()" />
		</xsl:copy>
	</xsl:template>
	
	<xsl:template match="subdomain">
		<xsl:copy>
			<xsl:if test="count(@shared-content) = 0">
				<xsl:attribute name="shared-content">
					<xsl:text>false</xsl:text>
				</xsl:attribute>
			</xsl:if>
			<xsl:apply-templates select="@*|node()" />
		</xsl:copy>
	</xsl:template>

	<xsl:template match="admin/domains | client/domains | reseller/clients">
    <xsl:copy>
      <xsl:apply-templates select="@*|node()" />
    </xsl:copy>
		<xsl:if test="count(../domains/descendant::domainuser) > 0 or count(../domains/descendant::mailuser-permission[@name = 'cp-access']) > 0">
			<xsl:element name="users">
				<xsl:call-template name="createDomainAdminUsers"/>
				<xsl:call-template name="createUserForMailUsers"/>
			</xsl:element>
			<xsl:element name="roles">
				<xsl:call-template name="createDomainAdminRoles"/>
				
				<xsl:if test="count(../domains/descendant::mailuser-permission[@name = 'cp-access' and @value = 'true']) > 0">
					<xsl:if test="count(../domains/descendant::limits-and-permissions[
									mailuser-permission[@name = 'cp-access' and @value = 'true'] and
									mailuser-permission[@name = 'manage-spamfilter' and @value = 'true'] and 
									mailuser-permission[@name = 'manage-virusfilter' and @value = 'true']]) > 0">
						<xsl:call-template name="createMailUserRole">
							<xsl:with-param name="name">Mail User (antispam; antivirus)</xsl:with-param>
							<xsl:with-param name="antivirus">true</xsl:with-param>
							<xsl:with-param name="spamfilter">true</xsl:with-param>
						</xsl:call-template>
					</xsl:if>
					<xsl:if test="count(../domains/descendant::limits-and-permissions[
									mailuser-permission[@name = 'cp-access' and @value = 'true'] and
									mailuser-permission[@name = 'manage-spamfilter' and @value = 'true'] and 
									not(mailuser-permission[@name = 'manage-virusfilter' and @value = 'true'])]) > 0">
						<xsl:call-template name="createMailUserRole">
							<xsl:with-param name="name">Mail User (antispam)</xsl:with-param>
							<xsl:with-param name="spamfilter">true</xsl:with-param>
						</xsl:call-template>
					</xsl:if>
					<xsl:if test="count(../domains/descendant::limits-and-permissions[
									mailuser-permission[@name = 'cp-access' and @value = 'true'] and
									not(mailuser-permission[@name = 'manage-spamfilter' and @value = 'true']) and 
									mailuser-permission[@name = 'manage-virusfilter' and @value = 'true']]) > 0">
						<xsl:call-template name="createMailUserRole">
							<xsl:with-param name="name">Mail User (antivirus)</xsl:with-param>
							<xsl:with-param name="antivirus">true</xsl:with-param>
						</xsl:call-template>
					</xsl:if>
					<xsl:if test="count(../domains/descendant::limits-and-permissions[
									mailuser-permission[@name = 'cp-access' and @value = 'true'] and
									not(mailuser-permission[@name = 'manage-spamfilter' and @value = 'true']) and 
									not(mailuser-permission[@name = 'manage-virusfilter' and @value = 'true'])]) > 0">
						<xsl:call-template name="createMailUserRole">
							<xsl:with-param name="name">Mail User</xsl:with-param>
						</xsl:call-template>
					</xsl:if>
				</xsl:if>
				
			</xsl:element>
		</xsl:if>
	</xsl:template>

	<xsl:template name ="createUserForMailUsers">
		<xsl:for-each select="../domains/descendant::mailuser[limits-and-permissions/mailuser-permission[@name = 'cp-access' and @value = 'true']]">
			<xsl:element name="user">
				<xsl:attribute name="name">
					<xsl:value-of select="concat(@name, '@', ./ancestor::domain/@name)"/>
				</xsl:attribute>
				<xsl:attribute name="contact">
					<xsl:value-of select="@name"/>
				</xsl:attribute>
				<xsl:attribute name="guid"/>
				<xsl:attribute name="email">
					<xsl:value-of select="concat(@name, '@', ./ancestor::domain/@name)"/>
				</xsl:attribute>
				<xsl:attribute name="is-domain-admin">
					<xsl:text>false</xsl:text>
				</xsl:attribute>
				<xsl:attribute name="is-built-in">
					<xsl:text>false</xsl:text>
				</xsl:attribute>

				<xsl:element name="properties">
					<xsl:choose>
						<xsl:when test="count(properties/password) > 0">
							<xsl:copy-of select="properties/password"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:element name="password">
								<xsl:attribute name="type">
									<xsl:text>empty</xsl:text>
								</xsl:attribute>
							</xsl:element>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:element name="status">
						<xsl:element name="enabled"/>
					</xsl:element>
				</xsl:element>
				
				<xsl:element name="limits-and-permissions">
					<xsl:element name="role-ref">
						<xsl:call-template name="createMailUserRoleName"/>
					</xsl:element>
				</xsl:element>

				<xsl:element name="preferences"/>
				
			</xsl:element>
		</xsl:for-each>
	</xsl:template>

	<xsl:template name="createMailUserRole">
		<xsl:param name="name"/>
		<xsl:param name="antivirus"/>
		<xsl:param name="spamfilter"/>
		<xsl:element name="role">
			<xsl:attribute name="name">
				<xsl:value-of select="$name"/>
			</xsl:attribute>
			<xsl:attribute name="is-built-in">
				<xsl:text>false</xsl:text>
			</xsl:attribute>
			<xsl:element name="limits-and-permissions">
				<xsl:if test="$antivirus = 'true'">
					<xsl:call-template name="rolePermission">
						<xsl:with-param name="name">antivirusManagement</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="$spamfilter = 'true'">
					<xsl:call-template name="rolePermission">
						<xsl:with-param name="name">spamfilterManagement</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
			</xsl:element>
		</xsl:element>
	</xsl:template>

	<xsl:template name="createMailUserRoleName">
		<xsl:choose>
			<xsl:when test="count(limits-and-permissions/mailuser-permission[@name = 'manage-spamfilter' and @value = 'true']) > 0 and count(limits-and-permissions/mailuser-permission[@name = 'manage-virusfilter' and @value = 'true']) > 0">
				<xsl:text>Mail User (antispam; antivirus)</xsl:text>
			</xsl:when>
			<xsl:when test="count(limits-and-permissions/mailuser-permission[@name = 'manage-spamfilter' and @value = 'true']) > 0">
				<xsl:text>Mail User (antispam)</xsl:text>
			</xsl:when>
			<xsl:when test="count(limits-and-permissions/mailuser-permission[@name = 'manage-virusfilter' and @value = 'true']) > 0">
				<xsl:text>Mail User (antivirus)</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>Mail User</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="createDomainAdminUsers">
		<xsl:for-each select="../domains/descendant::domainuser">
			<xsl:element name="user">
				<xsl:attribute name="name">
					<xsl:value-of select="../@name"/>
				</xsl:attribute>
				<xsl:attribute name="contact">
					<xsl:choose>
						<xsl:when test="count(pinfo[@name = 'name']) > 0 and pinfo[@name = 'name'] != ''">
							<xsl:value-of select="pinfo[@name = 'name']"/>
						</xsl:when>
						<xsl:otherwise>
       						<xsl:choose>
								<xsl:when test="@contact != ''">
									<xsl:value-of select="@contact"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="../@name"/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
				<xsl:attribute name="guid"/>
				<xsl:attribute name="email">
					<xsl:value-of select="pinfo[@name = 'email']"/>
				</xsl:attribute>
				<xsl:attribute name="is-domain-admin">
					<xsl:text>true</xsl:text>
				</xsl:attribute>
				<xsl:attribute name="is-built-in">
					<xsl:text>false</xsl:text>
				</xsl:attribute>

				<xsl:element name="properties">
					<xsl:choose>
						<xsl:when test="count(password) > 0">
							<xsl:copy-of select="password"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:element name="password">
								<xsl:attribute name="type">
									<xsl:text>empty</xsl:text>
								</xsl:attribute>
							</xsl:element>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:element name="status">
							<xsl:element name="disabled-by">
								<xsl:attribute name="name">
									<xsl:text>admin</xsl:text>
								</xsl:attribute>
							</xsl:element>
					</xsl:element>
				</xsl:element>
				
				<xsl:element name="limits-and-permissions">
					<xsl:element name="role-ref">
						<xsl:call-template name="createDomainAdminRoleName"/>
					</xsl:element>
				</xsl:element>

				<xsl:element name="preferences">
					<xsl:apply-templates select="pinfo[@name != 'locale']"/>
				</xsl:element>
				
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="createDomainAdminRoles">
		<xsl:for-each select="./descendant::domainuser">
			<xsl:element name="role">
				<xsl:attribute name="name">
					<xsl:call-template name="createDomainAdminRoleName"/>
				</xsl:attribute>
				<xsl:attribute name="is-built-in">
					<xsl:text>false</xsl:text>
				</xsl:attribute>
				<xsl:element name="limits-and-permissions">
					<xsl:if test="permission[@name = 'manage_log']/@value = 'true'">
						<xsl:call-template name="rolePermission">
							<xsl:with-param name="name">logRotationManagement</xsl:with-param>
						</xsl:call-template>
					</xsl:if>
					<xsl:if test="permission[@name = 'manage_anonftp']/@value = 'true'">
						<xsl:call-template name="rolePermission">
							<xsl:with-param name="name">anonymousFtpManagement</xsl:with-param>
						</xsl:call-template>
					</xsl:if>
					<xsl:if test="permission[@name = 'manage_crontab']/@value = 'true'">
						<xsl:call-template name="rolePermission">
							<xsl:with-param name="name">scheduledTasksManagement</xsl:with-param>
						</xsl:call-template>
					</xsl:if>
					<xsl:if test="permission[@name = 'manage_spamfilter']/@value = 'true'">
						<xsl:call-template name="rolePermission">
							<xsl:with-param name="name">spamfilterManagement</xsl:with-param>
						</xsl:call-template>
					</xsl:if>
					<xsl:if test="permission[@name = 'manage_virusfilter']/@value = 'true'">
						<xsl:call-template name="rolePermission">
							<xsl:with-param name="name">antivirusManagement</xsl:with-param>
						</xsl:call-template>
					</xsl:if>
					<xsl:if test="permission[@name = 'allow_local_backups']/@value = 'true' or permission[@name = 'allow_ftp_backups']/@value = 'true'">
						<xsl:call-template name="rolePermission">
							<xsl:with-param name="name">backupRestoreManagement</xsl:with-param>
						</xsl:call-template>
					</xsl:if>
					<xsl:if test="permission[@name = 'manage_dns']/@value = 'true'">
						<xsl:call-template name="rolePermission">
							<xsl:with-param name="name">dnsManagement</xsl:with-param>
						</xsl:call-template>
					</xsl:if>
					<xsl:if test="permission[@name = 'manage_webapps']/@value = 'true'">
						<xsl:call-template name="rolePermission">
							<xsl:with-param name="name">javaApplicationsManagement</xsl:with-param>
						</xsl:call-template>
					</xsl:if>
					<xsl:if test="permission[@name = 'manage_maillists']/@value = 'true'">
						<xsl:call-template name="rolePermission">
							<xsl:with-param name="name">mailListsManagement</xsl:with-param>
						</xsl:call-template>
					</xsl:if>
				</xsl:element>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>

	<xsl:template name="createDomainAdminRoleName">
		<xsl:value-of select="concat('Domain Administrator (', ../@name, ')')"/>
	</xsl:template>
	
	<xsl:template name="rolePermission">
		<xsl:param name="name"/>
			<xsl:element name="permission">
				<xsl:attribute name="name">
					<xsl:value-of select="$name"/>
				</xsl:attribute>
				<xsl:attribute name="value">
					<xsl:text>true</xsl:text>
				</xsl:attribute>
			</xsl:element>
	</xsl:template>
	
	<xsl:template match="mailuser/@mailgroup-enabled">
		<xsl:attribute name="forwarding-enabled">
			<xsl:value-of select="."/>
		</xsl:attribute>
	</xsl:template>
	
	<xsl:template match="mailuser/preferences/mailgroup-member">
		<xsl:element name="forwarding">
			<xsl:value-of select="."/>
		</xsl:element>
	</xsl:template>
	
	<xsl:template match="mailuser/preferences/redirect">
		<xsl:element name="forwarding">
			<xsl:value-of select="."/>
		</xsl:element>
	</xsl:template>
	
	<xsl:template match="autoresponders">
		<xsl:copy>
			<xsl:apply-templates select="
					 *[local-name(.) != 'autoresponder']
					 | autoresponder[count(@status) = 0 or @status = 'on'][last()]"/>
		</xsl:copy>
	</xsl:template>

	<xsl:template match="autoresponder/@status">
		<xsl:attribute name="status">
			<xsl:choose>
				<xsl:when test="../../@enabled = 'true'">
					<xsl:text>on</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>off</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:attribute>
	</xsl:template>

	<xsl:template match="autoresponder/@content-type[. = 'html']">
		<xsl:attribute name="content-type">
			<xsl:text>text/html</xsl:text>
		</xsl:attribute>
	</xsl:template>
	

	<xsl:template match="sapp-package">
		<xsl:copy>
			<xsl:apply-templates select="@*|node()" />
			<xsl:element name="sapp-uploaded"/>
			<xsl:element name="sapp-visible"/>
		</xsl:copy>
	</xsl:template>
	
	<xsl:template match="@*|node()">
    <xsl:copy>
      <xsl:apply-templates select="@*|node()" />
    </xsl:copy>
  </xsl:template>
	
</xsl:stylesheet> 
