<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	
	<xsl:output method="xml" indent="yes"/>

	<xsl:param name="convert-mailnames-to-users"/>
	<xsl:param name="import-anti-spam-training"/>
	<xsl:param name="mail-lists-owner"/>
	<xsl:param name="migrated-users-role"/>
	<xsl:param name="domains-owner-guid"/>
	<xsl:param name="default-ip"/>
	<xsl:param name="default-ip-type"/>
	
	<xsl:template match="/migration-dump">
		<xsl:copy>
			<xsl:copy-of select="./@*"/>
			<xsl:attribute name="dump-format">
				<xsl:text>PleskToSmb</xsl:text>
			</xsl:attribute>
			<xsl:apply-templates select="dump-info"/>

			<xsl:apply-templates select="//domain"/>
			
			<xsl:if test="$convert-mailnames-to-users = 'true'">
				<xsl:apply-templates select="//mailuser[count(preferences/mailgroup-member) = 0]" mode="createSmbUser"/>
			</xsl:if>

			<xsl:choose>
				<xsl:when test="count(server) > 0">
					<xsl:apply-templates select="server"/>
				</xsl:when>
				<xsl:when test="count(server) = 0 and count(//domain/certificates/certificate) > 0">
					<xsl:element name="server">
						<xsl:element name="certificates">
							<xsl:apply-templates select="//domain/certificates/certificate"/>
						</xsl:element>
					</xsl:element>
				</xsl:when>
			</xsl:choose>
			
		</xsl:copy>
	</xsl:template>

	<xsl:template match="mailuser" mode="createSmbUser">
		<xsl:element name="user">
			<xsl:attribute name="name">
				<xsl:value-of select="@name"/>
			</xsl:attribute>
			<xsl:attribute name="contact">
				<xsl:value-of select="concat(@name, '_', ../../../@name)"/>
			</xsl:attribute>
			<xsl:attribute name="guid"/>
			<xsl:attribute name="email">
				<xsl:value-of select="concat(@name, '@', ../../../@name)"/>
			</xsl:attribute>
			<xsl:attribute name="is-built-in">
				<xsl:text>false</xsl:text>
			</xsl:attribute>
			<xsl:element name="properties">
				<xsl:copy-of select="properties/password"/>
				<xsl:element name="status">
					<xsl:element name="enabled"/>
				</xsl:element>
			</xsl:element>
			<xsl:element name="limits-and-permissions">
				<xsl:element name="role-ref">
					<xsl:value-of select="$migrated-users-role"/>
				</xsl:element>
			</xsl:element>
			<xsl:element name="preferences">
				<xsl:element name="pinfo">
					<xsl:attribute name="name">
						<xsl:text>email</xsl:text>
					</xsl:attribute>
					<xsl:value-of select="concat(@name, '@', ../../../@name)"/>
				</xsl:element>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	
	<xsl:template match="autoresponders">
		<xsl:if test="count(autoresponder[count(@require) = 0]) > 0">
			<xsl:copy>
				<xsl:copy-of select="./@*"/>
				<xsl:apply-templates select="autoresponder[count(@require) = 0][1]"/>
			</xsl:copy>
		</xsl:if>
	</xsl:template>

	<xsl:template match="autoresponder">
    <xsl:copy>
      <xsl:apply-templates select="@*[local-name(.) != 'require']" />
      <xsl:apply-templates select="node()" />
    </xsl:copy>
  </xsl:template>

	<xsl:template match="domain">
		<xsl:copy>
			<xsl:copy-of select="./@*[local-name(.) != 'owner-guid']"/>
			<xsl:attribute name="owner-guid">
				<xsl:value-of select="$domains-owner-guid"/>
			</xsl:attribute>
			<xsl:apply-templates select="content"/>
			<xsl:apply-templates select="preferences"/>
			<xsl:apply-templates select="properties"/>
			<xsl:apply-templates select="mailsystem"/>
			<xsl:apply-templates select="databases"/>
			<xsl:choose>
				<xsl:when test="count(maillists) > 0">
					<xsl:apply-templates select="maillists"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:element name="maillists">
						<xsl:element name="status">
							<xsl:element name="enabled"/>
						</xsl:element>
						<xsl:apply-templates select="mailsystem/mailusers/mailuser[count(preferences/mailgroup-member) > 0]" mode="convertToMailList"/>
					</xsl:element>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:apply-templates select="traffic"/>
			<xsl:choose>
				<xsl:when test="count(phosting) > 0">
					<xsl:apply-templates select="phosting"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:element name="phosting">
						<xsl:attribute name="guid"/>
						<xsl:element name="preferences">
							<xsl:element name="sysuser">
								<xsl:attribute name="name">
									<xsl:value-of select="substring-before(@name, '.')"/>
								</xsl:attribute>
								<xsl:element name="password">
									<xsl:attribute name="type">
										<xsl:text>plain</xsl:text>
									</xsl:attribute>
								</xsl:element>
							</xsl:element>
						</xsl:element>
					</xsl:element>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:copy>
	</xsl:template>

	<xsl:template match="domain/properties/status">
		<xsl:copy>
			<xsl:choose>
				<xsl:when test="count(enabled) > 0">
					<xsl:apply-templates select="enabled"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:element name="disabled-by">
						<xsl:attribute name="name">
							<xsl:text>admin</xsl:text>
						</xsl:attribute>
					</xsl:element>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:copy>
	</xsl:template>
	<xsl:template match="phosting/content">
		<xsl:copy>
			<xsl:apply-templates select="@*|node()" />
		</xsl:copy>	
	</xsl:template>
	
	<xsl:template match="domain/properties">
		<xsl:copy>
			<xsl:if test="count(ip) = 0">
				<xsl:element name="ip">
					<xsl:element name="ip-type">
						<xsl:value-of select="$default-ip-type"/>
					</xsl:element>
					<xsl:element name="ip-address">
						<xsl:value-of select="$default-ip"/>
					</xsl:element>
				</xsl:element>
			</xsl:if>
			<xsl:apply-templates select="*"/>
		</xsl:copy>
	</xsl:template>

	<xsl:template match="domain/properties/dns-zone/dnsrec[@type='A']">
		<xsl:choose>
			<xsl:when test="(count(../../ip) = 0) and (contains(@src,../../../@name))">
				<dnsrec type="A" src="{@src}" dst="{$default-ip}" opt="{@opt}"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="domain/properties/dns-zone/dnsrec[@type='PTR']">
		<xsl:choose>
			<xsl:when test="(count(../../ip) = 0) and (contains(@dst,../../../@name))">
				<dnsrec type="PTR" src="{$default-ip}" dst="{@dst}" opt="{@opt}"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="domain/preferences/domain-alias/dns-zone/dnsrec[@type='A']">
		<xsl:choose>
			<xsl:when test="(count(../../../../domain/properties/ip) = 0) and (contains(@src,../../@name))">
				<dnsrec type="A" src="{@src}" dst="{$default-ip}" opt="{@opt}"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="domain/preferences/domain-alias/dns-zone/dnsrec[@type='PTR']">
		<xsl:choose>
			<xsl:when test="(count(../../../../domain/properties/ip) = 0) and (contains(@dst,../../@name))">
				<dnsrec type="PTR" src="{$default-ip}" dst="{@dst}" opt="{@opt}"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="
								custom-button 
								| webuser/scripting
								| webuser/sysuser
								| frontpageusers 
								| mime-types 
								| hotlink-protection 
								| limits-and-permissions[local-name(..) != 'phosting']
								| pdir 
								| shared-ssl
								| logrotation
								| iis-application-pool
								| phosting/preferences/perfomance
								| subdomain/preferences
								| mailsystem/preferences
								| autoresponders/content
								| autoresponders/attach
								| autoresponder/autoresponder-limit
								| autoresponder/attach
								| mailuser/preferences/virusfilter
								| mailuser/preferences/addressbook
								| mailbox/@enabled
								| sysuser/cron								
								| tomcat
								">
	</xsl:template>
	
	<xsl:template match="cid[
								@type = 'vdirs' 
								or @type = 'error_docs' 
								or @type = 'error_docs_cfg' 
								or @type = 'aspnet_config'
								or @type = 'attaches'
								]">
	</xsl:template>

	<xsl:template match="sapp-installed/content/cid">
		<xsl:copy>
			<xsl:apply-templates select="./@*[local-name(.) != 'offset']"/>
			<xsl:if test="count(@offset) = 1">
				<xsl:attribute name="offset">
					<xsl:choose>
						<xsl:when test="contains(@offset, '/.') and substring-after(@offset, '/.') = ''">
							<xsl:value-of select="substring(@offset, 1, string-length(@offset) - 1)"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="@offset"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</xsl:if>
			<xsl:apply-templates select="./*"/>
		</xsl:copy>
	</xsl:template>

	<xsl:template match="sapp-prefix">
		<xsl:copy>
			<xsl:if test=". != '.'">
				<xsl:value-of select="."/>
			</xsl:if>
		</xsl:copy>
	</xsl:template>
	
	
	<xsl:template match="mailusers">
		<xsl:if test="count(mailuser[count(preferences/mailgroup-member) = 0]) > 0">
			<xsl:copy>
				<xsl:apply-templates select="./* | ./@*"/>
			</xsl:copy>
		</xsl:if>
	</xsl:template>

	<xsl:template match="mailuser">
		<xsl:if test="count(preferences/mailgroup-member) = 0">
			<xsl:copy>
				<xsl:apply-templates select="./* | @id | @guid | @name"/>
			</xsl:copy>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="maillists">
		<xsl:copy>
			<xsl:copy-of select="./@*"/>
			<xsl:apply-templates select="content"/>
			<xsl:apply-templates select="status"/>
			<xsl:apply-templates select="maillist"/>
			<xsl:apply-templates select="../mailsystem/mailusers/mailuser[count(preferences/mailgroup-member) > 0]" mode="convertToMailList"/>
		</xsl:copy>
	</xsl:template>
	
	<xsl:template match="mailuser[count(preferences/mailgroup-member) > 0]" mode="convertToMailList">
		<xsl:element name="maillist">
			<xsl:attribute name="name">
				<xsl:value-of select="@name"/>
			</xsl:attribute>
			<xsl:element name="status">
				<xsl:choose>
					<xsl:when test="@mailgroup-enabled = 'true'">
						<xsl:element name="enabled"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:element name="disabled-by">
							<xsl:attribute name="name">
								<xsl:text>admin</xsl:text>
							</xsl:attribute>
						</xsl:element>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:element>
			<xsl:element name="owner">
				<xsl:value-of select="$mail-lists-owner"/>
			</xsl:element>
			<xsl:copy-of select="properties/password"/>
			<xsl:for-each select="preferences/mailgroup-member">
				<xsl:element name="recipient">
					<xsl:value-of select="."/>
				</xsl:element>
			</xsl:for-each>
			<xsl:if test="count(preferences/autoresponders/autoresponder) > 0">
				<xsl:element name="preferences">
					<xsl:apply-templates select="preferences/autoresponders"/>
				</xsl:element>
			</xsl:if>
		</xsl:element>
	</xsl:template>
	
	<xsl:template match="mailuser/preferences/spamassassin">
			<xsl:if test="$import-anti-spam-training = 'true'">
				<xsl:copy>
					<xsl:apply-templates select="content"/>
				</xsl:copy>
			</xsl:if>
	</xsl:template>

	<xsl:template match="server">
		<xsl:copy>
			<xsl:choose>
				<xsl:when test="count(certificates) > 0">
					<xsl:apply-templates select="certificates"/>
				</xsl:when>
				<xsl:when test="count(certificates) = 0 and count(//domain/certificates/certificate) > 0">
					<xsl:element name="certificates">
						<xsl:apply-templates select="//domain/certificates/certificate"/>
					</xsl:element>
				</xsl:when>
			</xsl:choose>
			<xsl:apply-templates select="application-vault"/>
		</xsl:copy>
	</xsl:template>
	
	<xsl:template match="@*|node()">
    <xsl:copy>
      <xsl:apply-templates select="@*|node()" />
    </xsl:copy>
  </xsl:template>
	
	<xsl:template match="server/certificates">
		<xsl:element name="certificates">
			<xsl:for-each select="certificate">
				<xsl:apply-templates select="."/>
			</xsl:for-each>
			<xsl:apply-templates select="//domain/certificates/certificate"/>
		</xsl:element>
	</xsl:template>
	
</xsl:stylesheet> 
