<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	
	<xsl:output method="xml" indent="yes"/>

	<xsl:template match="/migration-dump">
		<xsl:copy>
			<xsl:copy-of select="./@*"/>
			<xsl:attribute name="dump-format">
				<xsl:text>smb</xsl:text>
			</xsl:attribute>
			<xsl:apply-templates select="dump-info"/>
			<xsl:apply-templates select="node()[local-name(.) != 'dump-info']"/>
		</xsl:copy>
	</xsl:template>

	<xsl:template match="domain">
		<xsl:copy>
			<xsl:copy-of select="./@*"/>
			<xsl:apply-templates select="content 
									| preferences 
									| properties 
									| limits-and-permissions 
									| mailsystem 
									| databases 
									| odbc-dsn 
									| coldfusion-dsn"/>
			<xsl:choose>
				<xsl:when test="count(maillists) > 0">
					<xsl:apply-templates select="maillists"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:element name="maillists">
						<xsl:element name="status">
							<xsl:element name="enabled"/>
						</xsl:element>
						<xsl:apply-templates select="mailsystem/mailusers/mailuser[count(preferences/mailgroup-member) > 0 or (preferences/mailbox/@enabled = 'false' and properties/password = '')]" mode="convertToMailList"/>
					</xsl:element>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:apply-templates select="traffic 
									| certificates 
									| tomcat 
									| domainuser 
									| shosting 
									| phosting 
									| fhosting"/>
		</xsl:copy>
	</xsl:template>

	
	<xsl:template match="mailusers">
		<xsl:if test="count(mailuser[count(preferences/mailgroup-member) = 0 and (preferences/mailbox/@enabled != 'false' or properties/password != '')]) > 0">
			<xsl:copy>
				<xsl:apply-templates select="./* | ./@*"/>
			</xsl:copy>
		</xsl:if>
	</xsl:template>

	<xsl:template match="mailuser">
		<xsl:if test="count(preferences/mailgroup-member) = 0 and (preferences/mailbox/@enabled != 'false' or properties/password != '')">
			<xsl:copy>
				<xsl:apply-templates select="./* | @id | @guid | @name"/>
			</xsl:copy>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="maillists">
		<xsl:copy>
			<xsl:copy-of select="./@*"/>
			<xsl:apply-templates select="content | status | maillist"/>
			<xsl:apply-templates select="../mailsystem/mailusers/mailuser[count(preferences/mailgroup-member) > 0 or (preferences/mailbox/@enabled = 'false' and properties/password = '')]" mode="convertToMailList"/>
		</xsl:copy>
	</xsl:template>
	
	<xsl:template match="mailuser[count(preferences/mailgroup-member) > 0 or (preferences/mailbox/@enabled = 'false' and properties/password = '')]" mode="convertToMailList">
		<xsl:element name="maillist">
			<xsl:attribute name="name">
				<xsl:value-of select="@name"/>
			</xsl:attribute>
			<xsl:element name="status">
				<xsl:choose>
					<xsl:when test="@mailgroup-enabled = 'true'">
						<xsl:element name="enabled"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:element name="disabled-by">
							<xsl:attribute name="name">
								<xsl:text>admin</xsl:text>
							</xsl:attribute>
						</xsl:element>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:element>
			<xsl:copy-of select="properties/password"/>
			<xsl:for-each select="preferences/mailgroup-member">
				<xsl:element name="recipient">
					<xsl:value-of select="."/>
				</xsl:element>
			</xsl:for-each>
			<xsl:if test="count(preferences/autoresponders/autoresponder) > 0">
				<xsl:element name="preferences">
					<xsl:apply-templates select="preferences/autoresponders"/>
				</xsl:element>
			</xsl:if>
		</xsl:element>
	</xsl:template>
	
	<xsl:template match="@*|node()">
    <xsl:copy>
      <xsl:apply-templates select="@*|node()" />
    </xsl:copy>
  </xsl:template>
	
</xsl:stylesheet> 
